@@ -64,11 +64,14 @@ init_commands(void)
 	help_init();
 	imap_init();
 	inject_init();
+	madvise_init();
+	mincore_init();
 	mmap_init();
 	open_init();
 	parent_init();
 	pread_init();
 	prealloc_init();
+	fiemap_init();
 	pwrite_init();
 	quit_init();
 	resblks_init();
